==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Partage fédéré",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} depuis {owner}@{remote} ?",
    "Remote share" : "Partage distant",
    "Remote share password" : "Mot de passe du partage distant",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "Copy" : "Copier",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté!",
    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "Couldn't establish a federated share." : "Impossible d'établir un partage fédéré.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossible d'établir un partage fédéré, peut-être que le mot de passe est incorrect.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "La demande de partage fédéré est réussie, vous allez recevoir une invitation. Vérifiez vos notifications.",
    "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères invalides.",
    "Not allowed to create a federated share with the owner." : "Vous n'êtes pas autorisé à créer un partage fédéré avec le propriétaire.",
    "Invalid or untrusted SSL certificate" : "Certificat SSL invalide ou non approuvé",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de se connecter au partage distant, le mot de passe peut-être incorrect",
    "Storage not valid" : "Support de stockage non valide",
    "Federated Share successfully added" : "Partage fédéré ajouté avec succès",
    "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec %s",
    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %s a échoué, impossible de trouver %s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
    "Could not find share" : "Impossible de trouver le partage",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous avez reçu  \"%3$s\" en tant que partage distant de %1$s (de la part de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vous avez reçu {share} comme partage distant de la part de {user} (de la part de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Vous avez reçu \"%3$s\" comme partage distant de %1$s",
    "You received {share} as a remote share from {user}" : "Vous avez reçu {share} comme partage distant de la part de {user}",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant Federated Cloud #Nextcloud %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant Federated Cloud #Nextcloud",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Voir la documentation",
    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
    "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Votre identifiant Federated Cloud :",
    "Share it:" : "Partager :",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
    "HTML Code:" : "Code HTML :",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Le partage de %s a échoué : impossible de trouver %s. Peut-être le serveur est-il momentanément injoignable.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous avez reçu  \"/%3$s\" en tant que ressource distante de %1$s (de la part de %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Vous avez reçu \"/%3$s\" comme partage distant de %1$s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/fr.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Partage fédéré",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voulez-vous ajouter le partage distant {name} depuis {owner}@{remote} ?",
    "Remote share" : "Partage distant",
    "Remote share password" : "Mot de passe du partage distant",
    "Cancel" : "Annuler",
    "Add remote share" : "Ajouter un partage distant",
    "Copy" : "Copier",
    "Copied!" : "Copié !",
    "Not supported!" : "Non supporté!",
    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
    "Invalid Federated Cloud ID" : "ID Federated Cloud incorrect",
    "Server to server sharing is not enabled on this server" : "Le partage de serveur à serveur n'est pas activé sur ce serveur",
    "Couldn't establish a federated share." : "Impossible d'établir un partage fédéré.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossible d'établir un partage fédéré, peut-être que le mot de passe est incorrect.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Demande de partage fédéré envoyée, vous allez recevoir une invitation. Vérifiez vos notifications.",
    "The mountpoint name contains invalid characters." : "Le nom du point de montage contient des caractères invalides.",
    "Not allowed to create a federated share with the owner." : "Vous n'êtes pas autorisé à créer un partage fédéré avec le propriétaire.",
    "Invalid or untrusted SSL certificate" : "Certificat SSL invalide ou non approuvé",
    "Could not authenticate to remote share, password might be wrong" : "Impossible de se connecter au partage distant, le mot de passe peut-être incorrect",
    "Storage not valid" : "Support de stockage non valide",
    "Federated share added" : "Partage fédéré ajouté",
    "Couldn't add remote share" : "Impossible d'ajouter le partage distant",
    "Sharing %s failed, because this item is already shared with %s" : "Le partage de %s a échoué car cet élément est déjà partagé avec %s",
    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
    "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %s a échoué, impossible de trouver %s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
    "Could not find share" : "Impossible de trouver le partage",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Vous avez reçu \"%3$s\" en tant que partage distant de %1$s (de la part de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vous avez reçu {share} comme partage distant de la part de {user} (de la part de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Vous avez reçu \"%3$s\" comme partage distant de %1$s",
    "You received {share} as a remote share from {user}" : "Vous avez reçu {share} comme partage distant de la part de {user}",
    "Accept" : "Accepter",
    "Decline" : "Refuser",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant Federated Cloud #Nextcloud %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant Federated Cloud #Nextcloud",
    "Sharing" : "Partage",
    "Federated file sharing" : "Partage de fichiers fédérés",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Open documentation" : "Voir la documentation",
    "Adjust how people can share between servers." : "Réglez comment les personnes peuvent partager entre les serveurs.",
    "Allow users on this server to send shares to other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs",
    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
    "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
    "Allow users to publish their data to a global and public address book" : "Autoriser les utilisateurs à publier leurs données dans un carnet d'adresse global et public",
    "Federated Cloud" : "Federated Cloud",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec n'importe qui qui utilise Nextcloud, ownCloud ou Pydio ! Renseignez simplement leur Federated Cloud ID dans la boîte de dialogue de partage. Cela ressemble à person@cloud.example.com",
    "Your Federated Cloud ID:" : "Votre identifiant Federated Cloud :",
    "Share it so your friends can share files with you:" : "Partagez-le afin que vos amis puissent partager des fichiers avec vous :",
    "Add to your website" : "Ajouter à votre site web",
    "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
    "HTML Code:" : "Code HTML :",
    "Search global and public address book for users and let local users publish their data" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs et laisser les utilisateurs publier leurs données",
    "Share it:" : "Partager :"
},
"nplurals=2; plural=(n > 1);");
